@@ -97,41 +97,6 @@ dependencies:
         Ok(())
     }
 
-    fn output_test(&self, install_dir: &Path) -> Result<()> {
-        let test_dir_path = install_dir.join("test");
-        std::fs::create_dir_all(&test_dir_path)?;
-
-        let mut file = std::fs::File::create(test_dir_path.join("all_test.dart".to_string()))?;
-        let mut out = IndentedWriter::new(&mut file, IndentConfig::Space(2));
-        writeln!(&mut out, r#"import 'package:test/test.dart';"#,)?;
-
-        writeln!(
-            &mut out,
-            r#"
-import 'src/serde.dart';
-"#
-        )?;
-        for encoding in &self.config.encodings {
-            writeln!(&mut out, "import 'src/{}.dart';", encoding.name())?;
-        }
-
-        writeln!(
-            &mut out,
-            r#"void main() {{
-  group('Serde', runSerdeTests);"#,
-        )?;
-        for encoding in &self.config.encodings {
-            writeln!(
-                &mut out,
-                "  group('{0}', run{0}Tests);",
-                encoding.name().to_camel_case()
-            )?;
-        }
-
-        writeln!(&mut out, "}}")?;
-        Ok(())
-    }
-
     fn write_library(
         &self,
         install_dir: &Path,
@@ -1013,7 +978,7 @@ switch (index) {{"#,
             }
             writeln!(
                 self.out,
-                "default: throw new Exception(\"Unknown variant index for {}: \" + index.toString());",
+                "default: throw Exception(\"Unknown variant index for {}: \" + index.toString());",
                 self.quote_qualified_name(name),
             )?;
             self.out.unindent();
@@ -1099,7 +1064,7 @@ switch (index) {{"#,
             }
             writeln!(
                 self.out,
-                "default: throw new Exception(\"Unknown variant index for {}: \" + index.toString());",
+                "default: throw Exception(\"Unknown variant index for {}: \" + index.toString());",
                 self.quote_qualified_name(name),
             )?;
             self.out.unindent();
@@ -1217,9 +1182,6 @@ impl crate::SourceInstaller for Installer {
     ) -> std::result::Result<(), Self::Error> {
         let generator = CodeGenerator::new(config);
         generator.output(self.install_dir.clone(), registry)?;
-        generator.output_test(&self.install_dir)?;
-        self.install_runtime(include_directory!("runtime/dart/test"), "test/src")?;
-
         // write the main module file to export the public api
         std::fs::write(
             self.install_dir
